pub enum RetentionRule {
KeepFrameKind(FrameKind),
KeepScope(Scope),
KeepRecent {
min_sequence: u64,
},
DropWrittenBefore {
older_than_unix_ms: u64,
},
DropLastAccessedBefore {
older_than_unix_ms: u64,
},
DropOutsideScope {
required_scope: Option<Scope>,
},
KeepLabel(String),
DropLabel(String),
}Expand description
One deterministic retention rule.
Variants
KeepFrameKind(FrameKind)
Keep candidates whose frame kind matches kind.
KeepScope(Scope)
Keep candidates whose normalized scope exactly matches this scope.
KeepRecent
Keep candidates at or above min_sequence, where larger sequence
values are newer.
DropWrittenBefore
Drop candidates whose write timestamp is older than older_than_unix_ms.
Fields
DropLastAccessedBefore
Drop candidates whose last-access timestamp is older than
older_than_unix_ms.
Fields
DropOutsideScope
Drop candidates whose normalized scope does not exactly match
required_scope. None requires an unscoped candidate.
KeepLabel(String)
Keep candidates with a host-defined retention label.
DropLabel(String)
Drop candidates with a host-defined retention label.
Implementations
Sourceimpl RetentionRule
impl RetentionRule
Sourcepub fn evaluate(&self, candidate: RetentionCandidate<'_>) -> RetentionDecision
pub fn evaluate(&self, candidate: RetentionCandidate<'_>) -> RetentionDecision
Evaluate this rule against a single candidate.