RetentionRule

Enum RetentionRule 

pub enum RetentionRule {
    KeepFrameKind(FrameKind),
    KeepScope(Scope),
    KeepRecent {
        min_sequence: u64,
    },
    DropWrittenBefore {
        older_than_unix_ms: u64,
    },
    DropLastAccessedBefore {
        older_than_unix_ms: u64,
    },
    DropOutsideScope {
        required_scope: Option<Scope>,
    },
    KeepLabel(String),
    DropLabel(String),
}
One deterministic retention rule.

Variants



KeepFrameKind(FrameKind)

Keep candidates whose frame kind matches kind.



KeepScope(Scope)

Keep candidates whose normalized scope exactly matches this scope.



KeepRecent

Keep candidates at or above min_sequence, where larger sequence values are newer.

Fields

min_sequence: u64

Minimum sequence number to keep, where larger sequence values are newer.



DropWrittenBefore

Drop candidates whose write timestamp is older than older_than_unix_ms.

Fields

older_than_unix_ms: u64

Exclusive Unix-millisecond threshold; candidates written before this value are dropped.



DropLastAccessedBefore

Drop candidates whose last-access timestamp is older than older_than_unix_ms.

Fields

older_than_unix_ms: u64

Exclusive Unix-millisecond threshold; candidates last accessed before this value are dropped.



DropOutsideScope

Drop candidates whose normalized scope does not exactly match required_scope. None requires an unscoped candidate.

Fields

required_scope: Option<Scope>

Required exact scope. None requires candidates to be unscoped.



KeepLabel(String)

Keep candidates with a host-defined retention label.



DropLabel(String)

Drop candidates with a host-defined retention label.

Implementations

Source

impl RetentionRule

pub fn evaluate(&self, candidate: RetentionCandidate<'_>) -> RetentionDecision

Evaluate this rule against a single candidate.