pub trait Committable {
type Error: Error + Send + Sync + 'static;
// Required method
fn commit(&self) -> impl Future<Output = Result<(), Self::Error>>;
}Expand description
A backend that supports an explicit commit step to durably persist previously buffered writes.
Backends that persist on every write may still implement Committable
as a no-op so they can be used interchangeably in generic code.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".